==> re-admin-0.17.1.tgz: package/es/stores/authStore.js <==
import { style as _style } from 'antd/lib/message/style';
import _default from 'antd/lib/message';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _desc, _value, _class, _descriptor, _descriptor2;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _initDefineProp(target, property, descriptor, context) {
	if (!descriptor) return;
	Object.defineProperty(target, property, {
		enumerable: descriptor.enumerable,
		configurable: descriptor.configurable,
		writable: descriptor.writable,
		value: descriptor.initializer ? descriptor.initializer.call(context) : void 0
	});
}

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	var desc = {};
	Object['ke' + 'ys'](descriptor).forEach(function (key) {
		desc[key] = descriptor[key];
	});
	desc.enumerable = !!desc.enumerable;
	desc.configurable = !!desc.configurable;

	if ('value' in desc || desc.initializer) {
		desc.writable = true;
	}

	desc = decorators.slice().reverse().reduce(function (desc, decorator) {
		return decorator(target, property, desc) || desc;
	}, desc);

	if (context && desc.initializer !== void 0) {
		desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
		desc.initializer = undefined;
	}

	if (desc.initializer === void 0) {
		Object['define' + 'Property'](target, property, desc);
		desc = null;
	}

	return desc;
}

function _initializerWarningHelper(descriptor, context) {
	throw new Error('Decorating class property failed. Please ensure that transform-class-properties is enabled.');
}

import { observable } from 'mobx';
import cookie from '../utils/cookie';
import { ACCESS_TOKEN } from '../constants/CookieKeys';

import getRequest from '../utils/getRequest';
import { isString } from '../utils/fp';
import deprecated from '../utils/deprecated';
import showError from '../utils/showError';
import warning from 'warning';
import LocaleStores from './LocaleStores';

var locale = LocaleStores.ensure('requests');

var verifyAndSaveAccessToken = function verifyAndSaveAccessToken() {
	var authRes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
	var accessToken = authRes.accessToken,
	    expiresIn = authRes.expiresIn,
	    expiresInMilliseconds = authRes.expiresInMilliseconds;


	if (!isString(accessToken)) {
		throw new Error('"accessToken" is INVALID, received "' + accessToken + '"');
	}

	var maxAge = expiresInMilliseconds || expiresIn && expiresIn * 1000 || 0;

	process.env.NODE_ENV !== 'production' && (process.env.NODE_ENV !== 'production' ? warning(+maxAge, 'Missing `expiresIn` attribute.') : void 0);

	maxAge && cookie.set(ACCESS_TOKEN, accessToken, { maxAge: maxAge });
};

var AuthStore = (_class = function () {
	function AuthStore() {
		var _this = this;

		_classCallCheck(this, AuthStore);

		_initDefineProp(this, 'isFetching', _descriptor, this);

		_initDefineProp(this, 'accessToken', _descriptor2, this);

		this.getAccessToken = deprecated(function () {
			return _this.accessToken;
		}, '`getAccessToken()` is deprecated, please use `accessToken` instead');
	}

	_createClass(AuthStore, [{
		key: 'set',
		value: function set(config) {
			this._apiConfig = config.api;
			this._config = config.auth;
			process.env.NODE_ENV !== 'production' ? warning(this._config.basePath, 'Missing auth.basePath') : void 0;
			this._request = getRequest(config).clone(this._config.basePath);
		}
	}, {
		key: 'auth',
		value: function () {
			var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
				var isOk, options, accessTokenLocation, res, authRes;
				return regeneratorRuntime.wrap(function _callee$(_context) {
					while (1) {
						switch (_context.prev = _context.next) {
							case 0:
								this.isFetching = true;
								isOk = false;
								_context.prev = 2;
								options = { url: this._config.getUserPath };

								if (this.accessToken) {
									accessTokenLocation = this._apiConfig.accessTokenLocation;

									options[accessTokenLocation] = _defineProperty({}, this._apiConfig.accessTokenName, this.accessToken);
								}

								_context.next = 7;
								return this._request.fetch(options);

							case 7:
								res = _context.sent;
								authRes = this._config.mapOnGetUserResponse(res);

								verifyAndSaveAccessToken(authRes);
								this.accessToken = authRes.accessToken;
								isOk = true;
								_context.next = 18;
								break;

							case 14:
								_context.prev = 14;
								_context.t0 = _context['catch'](2);

								this.accessToken = null;
								showError(locale.data.invalidToken, _context.t0);

							case 18:
								this.isFetching = false;
								return _context.abrupt('return', isOk);

							case 20:
							case 'end':
								return _context.stop();
						}
					}
				}, _callee, this, [[2, 14]]);
			}));

			function auth() {
				return _ref.apply(this, arguments);
			}

			return auth;
		}()
	}, {
		key: 'login',
		value: function () {
			var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(body) {
				var isOk, res, authRes;
				return regeneratorRuntime.wrap(function _callee2$(_context2) {
					while (1) {
						switch (_context2.prev = _context2.next) {
							case 0:
								isOk = false;
								_context2.prev = 1;
								_context2.next = 4;
								return this._request.fetch({
									url: this._config.loginPath,
									method: 'POST',
									body: body
								});

							case 4:
								res = _context2.sent;
								authRes = this._config.mapOnLoginResponse(res);

								verifyAndSaveAccessToken(authRes);
								this.accessToken = authRes.accessToken;

								isOk = true;
								_default.success(locale.data.loginSuccessful);
								_context2.next = 16;
								break;

							case 12:
								_context2.prev = 12;
								_context2.t0 = _context2['catch'](1);

								this.accessToken = null;
								showError(locale.data.loginFailed, _context2.t0);

							case 16:
								return _context2.abrupt('return', isOk);

							case 17:
							case 'end':
								return _context2.stop();
						}
					}
				}, _callee2, this, [[1, 12]]);
			}));

			function login(_x2) {
				return _ref2.apply(this, arguments);
			}

			return login;
		}()
	}, {
		key: 'logout',
		value: function logout() {
			this.accessToken = null;
			cookie.remove(ACCESS_TOKEN);
		}
	}]);

	return AuthStore;
}(), (_descriptor = _applyDecoratedDescriptor(_class.prototype, 'isFetching', [observable], {
	enumerable: true,
	initializer: function initializer() {
		return true;
	}
}), _descriptor2 = _applyDecoratedDescriptor(_class.prototype, 'accessToken', [observable], {
	enumerable: true,
	initializer: function initializer() {
		return cookie.get(ACCESS_TOKEN);
	}
})), _class);


export default new AuthStore();

==> re-admin-0.18.0.tgz: package/es/stores/authStore.js <==
import { style as _style } from 'antd/lib/message/style';
import _default from 'antd/lib/message';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _desc, _value, _class, _descriptor, _descriptor2;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _initDefineProp(target, property, descriptor, context) {
	if (!descriptor) return;
	Object.defineProperty(target, property, {
		enumerable: descriptor.enumerable,
		configurable: descriptor.configurable,
		writable: descriptor.writable,
		value: descriptor.initializer ? descriptor.initializer.call(context) : void 0
	});
}

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	var desc = {};
	Object['ke' + 'ys'](descriptor).forEach(function (key) {
		desc[key] = descriptor[key];
	});
	desc.enumerable = !!desc.enumerable;
	desc.configurable = !!desc.configurable;

	if ('value' in desc || desc.initializer) {
		desc.writable = true;
	}

	desc = decorators.slice().reverse().reduce(function (desc, decorator) {
		return decorator(target, property, desc) || desc;
	}, desc);

	if (context && desc.initializer !== void 0) {
		desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
		desc.initializer = undefined;
	}

	if (desc.initializer === void 0) {
		Object['define' + 'Property'](target, property, desc);
		desc = null;
	}

	return desc;
}

function _initializerWarningHelper(descriptor, context) {
	throw new Error('Decorating class property failed. Please ensure that transform-class-properties is enabled.');
}

import { observable } from 'mobx';
import cookie from '../utils/cookie';
import { ACCESS_TOKEN } from '../constants/CookieKeys';

import getRequest from '../utils/getRequest';
import { isString, isFunction } from '../utils/fp';
import deprecated from '../utils/deprecated';
import showError from '../utils/showError';
import warning from 'warning';
import LocaleStores from './LocaleStores';

var locale = LocaleStores.ensure('requests');

var verifyAndSaveAccessToken = function verifyAndSaveAccessToken() {
	var authRes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
	var accessToken = authRes.accessToken,
	    expiresIn = authRes.expiresIn,
	    expiresInMilliseconds = authRes.expiresInMilliseconds;


	if (!isString(accessToken)) {
		throw new Error('"accessToken" is INVALID, received "' + accessToken + '"');
	}

	var maxAge = expiresInMilliseconds || expiresIn && expiresIn * 1000 || 0;

	process.env.NODE_ENV !== 'production' && (process.env.NODE_ENV !== 'production' ? warning(+maxAge, 'Missing `expiresIn` attribute.') : void 0);

	maxAge && cookie.set(ACCESS_TOKEN, accessToken, { maxAge: maxAge });
};

var AuthStore = (_class = function () {
	function AuthStore() {
		var _this = this;

		_classCallCheck(this, AuthStore);

		_initDefineProp(this, 'isFetching', _descriptor, this);

		_initDefineProp(this, 'accessToken', _descriptor2, this);

		this.getAccessToken = deprecated(function () {
			return _this.accessToken;
		}, '`getAccessToken()` is deprecated, please use `accessToken` instead');
	}

	_createClass(AuthStore, [{
		key: 'set',
		value: function set(config) {
			this._apiConfig = config.api;
			this._config = config.auth;
			process.env.NODE_ENV !== 'production' ? warning(this._config.basePath, 'Missing auth.basePath') : void 0;
			this._request = getRequest(config).clone(this._config.basePath);
		}
	}, {
		key: 'auth',
		value: function () {
			var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
				var isOk, options, accessTokenLocation, res, authRes;
				return regeneratorRuntime.wrap(function _callee$(_context) {
					while (1) {
						switch (_context.prev = _context.next) {
							case 0:
								this.isFetching = true;
								isOk = false;
								_context.prev = 2;
								options = { url: this._config.getUserPath };

								if (this.accessToken) {
									accessTokenLocation = this._apiConfig.accessTokenLocation;

									options[accessTokenLocation] = _defineProperty({}, this._apiConfig.accessTokenName, this.accessToken);
								}

								_context.next = 7;
								return this._request.fetch(options);

							case 7:
								res = _context.sent;
								authRes = this._config.mapOnGetUserResponse(res);

								verifyAndSaveAccessToken(authRes);
								this.accessToken = authRes.accessToken;
								isOk = true;
								_context.next = 18;
								break;

							case 14:
								_context.prev = 14;
								_context.t0 = _context['catch'](2);

								this.accessToken = null;
								showError(locale.data.invalidToken, _context.t0);

							case 18:
								this.isFetching = false;
								return _context.abrupt('return', isOk);

							case 20:
							case 'end':
								return _context.stop();
						}
					}
				}, _callee, this, [[2, 14]]);
			}));

			function auth() {
				return _ref.apply(this, arguments);
			}

			return auth;
		}()
	}, {
		key: 'login',
		value: function () {
			var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(body) {
				var isOk, crypto, res, authRes;
				return regeneratorRuntime.wrap(function _callee2$(_context2) {
					while (1) {
						switch (_context2.prev = _context2.next) {
							case 0:
								isOk = false;
								crypto = this._config.crypto;

								if (body && body.password && isFunction(crypto)) {
									body.password = crypto(body.password);
								}

								_context2.prev = 3;
								_context2.next = 6;
								return this._request.fetch({
									url: this._config.loginPath,
									method: 'POST',
									body: body,
									bodyTransformer: this._config.mapOnLoginRequestBody
								});

							case 6:
								res = _context2.sent;
								authRes = this._config.mapOnLoginResponse(res);

								verifyAndSaveAccessToken(authRes);
								this.accessToken = authRes.accessToken;

								isOk = true;
								_default.success(locale.data.loginSuccessful);
								_context2.next = 19;
								break;

							case 14:
								_context2.prev = 14;
								_context2.t0 = _context2['catch'](3);

								this.accessToken = null;
								console.error(_context2.t0);
								showError(locale.data.loginFailed, _context2.t0);

							case 19:
								return _context2.abrupt('return', isOk);

							case 20:
							case 'end':
								return _context2.stop();
						}
					}
				}, _callee2, this, [[3, 14]]);
			}));

			function login(_x2) {
				return _ref2.apply(this, arguments);
			}

			return login;
		}()
	}, {
		key: 'logout',
		value: function logout() {
			this.accessToken = null;
			cookie.remove(ACCESS_TOKEN);
		}
	}]);

	return AuthStore;
}(), (_descriptor = _applyDecoratedDescriptor(_class.prototype, 'isFetching', [observable], {
	enumerable: true,
	initializer: function initializer() {
		return true;
	}
}), _descriptor2 = _applyDecoratedDescriptor(_class.prototype, 'accessToken', [observable], {
	enumerable: true,
	initializer: function initializer() {
		return cookie.get(ACCESS_TOKEN);
	}
})), _class);


export default new AuthStore();
